@@ -71,6 +71,8 @@ _("Display Group Menu"),
 _("Display Settings Menu"),
 _("Go Back a Desktop"),
 _("Go Forward a Desktop"),
+/* fonts.pango.cfg */
+/* fonts.xft.cfg */
 /* matches.cfg */
 /* menus.cfg */
 _("Backgrounds"),
@@ -86,8 +88,8 @@ _("Show Magnifier"),
 /* enlightenment.menu */
 _("Enlightenment"),
 _("User Menus"),
-_("Desktop"),
 _("Settings"),
+_("Desktop"),
 _("Themes"),
 _("Maintenance"),
 _("Help"),
@@ -108,30 +110,21 @@ _("Query all cache usage"),
 _("Regenerate Menus"),
 /* settings.menu */
 _("Settings"),
-_("Enlightenment Settings ..."),
-_("Focus Settings ..."),
-_("Move & Resize Settings ..."),
-_("Window Placement Settings ..."),
-_("Multiple Desktop Settings ..."),
-_("Virtual Desktop Settings ..."),
-_("Pager Settings ..."),
-_("Menu Settings ..."),
-_("Autoraise Settings ..."),
-_("Tooltip Settings ..."),
-_("Audio Settings ..."),
-_("Group Settings ..."),
-_("Remember Settings ..."),
-_("Special FX Settings ..."),
-_("Desktop Background Settings ..."),
-_("Theme Transparency Settings ..."),
-_("Composite Settings ..."),
-_("Session Settings ..."),
-_("Miscellaneous Settings ..."),
+_("Settings"),
+_("Desktop"),
+_("Themes"),
+_("Maintenance"),
+_("Help"),
+_("About Enlightenment"),
+_("About this theme"),
+_("Restart"),
+_("Log Out"),
 /* winops.menu */
 _("Window Options"),
 _("Close"),
 _("Annihilate"),
 _("Iconify"),
+_("Leave Alone"),
 _("Raise"),
 _("Lower"),
 _("Shade/Unshade"),
@@ -166,8 +159,10 @@ _("Toggle Never Focus"),
 _("Toggle Click to Focus"),
 _("Toggle Never Use Area"),
 _("Toggle Button Grabs"),
+_("Toggle Autoshade"),
 /* winops_opacity.menu */
 _("Opacity"),
+_("Default"),
 _("20%"),
 _("40%"),
 _("60%"),
