@@ -30,7 +30,7 @@
 #include <X11/keysym.h>
 #include <X11/Xatom.h>
 
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
 #include <X11/extensions/Xinerama.h>
 #endif
 
@@ -168,13 +168,13 @@ CreateWindow(Window parent, int x, int y, int ww, int hh)
 static              Imlib_Image
 ImageLoad(const char *dir, const char *file)
 {
-   Imlib_Image         im;
    char                tmp[4096];
 
    Esnprintf(tmp, sizeof(tmp), "%s/%s", dir, file);
-   im = imlib_load_image(tmp);
+   if (!exists(tmp))
+      return NULL;
 
-   return im;
+   return imlib_load_image(tmp);
 }
 
 static              Imlib_Image
@@ -186,7 +186,15 @@ ImageLoadDox(const char *file)
 Imlib_Image
 ImageLoadDoc(const char *file)
 {
-   return ImageLoad(docdir, file);
+   Imlib_Image         im;
+
+   im = ImageLoad(docdir, file);
+   if (im)
+      return im;
+
+   im = ImageLoadDox(file);
+
+   return im;
 }
 
 static void
@@ -356,7 +364,7 @@ main(int argc, char **argv)
    t = 16;
    wx = (VRoot.w - w) / 2;
    wy = (VRoot.h - (h + t)) / 2;
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
    if (VRoot.win == DefaultRootWindow(disp) && XineramaIsActive(disp))
      {
 	Window              rt, ch;
