@@ -77,8 +77,7 @@ TextStateLoadFont(TextState * ts)
 	if (ss)
 	  {
 	     *ss = ' ';
-	     word(s2, 1, w);
-	     sprintf(s, "%s.ttf", w);
+	     word(s2, 1, s);
 	     word(s2, 2, w);
 	     ts->efont = Efont_load(s, atoi(w));
 	     if (ts->efont)
