@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2007 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -24,13 +24,16 @@
 #include "E.h"
 #include "dialog.h"
 
+#if ENABLE_DIALOGS
+
 static void
 _DlgFillAbout(Dialog * d, DItem * table, void *data __UNUSED__)
 {
    DItem              *di;
    char                buf[1024];
 
-   Esnprintf(buf, sizeof(buf), _("About Enlightenment %s"), e_wm_version);
+   Esnprintf(buf, sizeof(buf), _("About Enlightenment e16 version %s"),
+	     e_wm_version);
    DialogSetTitle(d, buf);
 
    DialogItemTableSetOptions(table, 2, 0, 0, 0);
@@ -40,8 +43,7 @@ _DlgFillAbout(Dialog * d, DItem * table, void *data __UNUSED__)
 
    di = DialogAddItem(table, DITEM_TEXT);
    Esnprintf(buf, sizeof(buf),
-	     _("Welcome to the %s version\n"
-	       "of the Enlightenment window manager.\n"
+	     _("Welcome to Enlightenment e16\n" "version %s.\n"
 	       "If you find a bug, please do not\n"
 	       "hesitate to send in a bug report.\n"
 	       "We hope you enjoy the software.\n" "\n"
@@ -70,3 +72,5 @@ About(void)
 {
    DialogShowSimple(&DlgAbout, NULL);
 }
+
+#endif /* ENABLE_DIALOGS */
