@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -933,7 +933,11 @@ ActionGetModifiers(Action * aa)
 static void
 handleAction(EWin * ewin, ActionType * action)
 {
+   if (ewin)
+      ewin->state.in_action = 1;
    EFunc(ewin, action->params);
+   if (ewin)
+      ewin->state.in_action = 0;
 
    /* Did we just hose ourselves? if so, we'd best not stick around here */
    if (mode_action_destroy)
@@ -1103,18 +1107,19 @@ ActionclassesGlobalEvent(XEvent * ev)
    return match;
 }
 
+static Timer       *ac_reload_timer = NULL;
+
 static int
 _ac_reload(void *data __UNUSED__)
 {
    AclassConfigLoadConfig("bindings.cfg");
+   ac_reload_timer = NULL;
    return 0;
 }
 
 void
 ActionclassesReload(void)
 {
-   static Timer       *ac_reload_timer;
-
    TIMER_DEL(ac_reload_timer);
    TIMER_ADD(ac_reload_timer, 0.2, _ac_reload, NULL);
 }
