@@ -47,6 +47,7 @@ Action             *ActionclassGetAction(ActionClass * ac, int ix);
 int                 ActionclassEvent(ActionClass * ac, XEvent * ev,
 				     EWin * ewin);
 int                 ActionclassesGlobalEvent(XEvent * ev);
+void                ActionclassesReload(void);
 
 const char         *ActionGetTooltipString(Action * aa);
 int                 ActionGetAnybutton(Action * aa);
@@ -54,7 +55,7 @@ int                 ActionGetEvent(Action * aa);
 int                 ActionGetButton(Action * aa);
 int                 ActionGetModifiers(Action * aa);
 
-void                GrabButtonGrabs(EWin * ewin);
-void                UnGrabButtonGrabs(EWin * ewin);
+void                GrabButtonGrabs(Win win);
+void                UnGrabButtonGrabs(Win win);
 
 #endif /* _ACLASS_H */
