@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -189,6 +189,7 @@ BackgroundImagesFree(Background * bg)
      }
 }
 
+#if ENABLE_DIALOGS
 static void
 BackgroundImagesKeep(Background * bg, int onoff)
 {
@@ -202,6 +203,7 @@ BackgroundImagesKeep(Background * bg, int onoff)
 	BackgroundImagesFree(bg);
      }
 }
+#endif /* ENABLE_DIALOGS */
 
 static void
 BackgroundFilesRemove(Background * bg)
@@ -248,6 +250,7 @@ BackgroundDestroy(Background * bg)
    return 0;
 }
 
+#if ENABLE_DIALOGS
 static void
 BackgroundDelete(Background * bg)
 {
@@ -276,6 +279,7 @@ BackgroundDelete(Background * bg)
 	  }
      }
 }
+#endif /* ENABLE_DIALOGS */
 
 static Background  *
 BackgroundCreate(const char *name, EColor * solid, const char *bgn, char tile,
@@ -889,6 +893,7 @@ BackgroundGetName(const Background * bg)
    return bg->name;
 }
 
+#if ENABLE_DIALOGS
 static const char  *
 BackgroundGetBgFile(const Background * bg)
 {
@@ -900,6 +905,7 @@ BackgroundGetFgFile(const Background * bg)
 {
    return bg->top.file;
 }
+#endif /* ENABLE_DIALOGS */
 
 Pixmap
 BackgroundGetPixmap(const Background * bg)
@@ -919,6 +925,7 @@ BackgroundIsNone(const Background * bg)
    return (bg) ? bg->external : 1;
 }
 
+#if ENABLE_DIALOGS
 static EImage      *
 BackgroundCacheMini(Background * bg, int keep, int nuke)
 {
@@ -951,6 +958,7 @@ BackgroundCacheMini(Background * bg, int keep, int nuke)
    EImageFree(im);
    return NULL;
 }
+#endif /* ENABLE_DIALOGS */
 
 #define S(str) ((str) ? str : "(null)")
 static void
@@ -1198,6 +1206,8 @@ BackgroundsConfigLoadUser(void)
    char                s[4096];
 
    Esnprintf(s, sizeof(s), "%s.backgrounds", EGetSavePrefix());
+   if (!exists(s))
+      Mode.backgrounds.force_scan = 1;
    ConfigFileLoad(s, NULL, ConfigFileRead, 0);
 }
 
@@ -1364,6 +1374,7 @@ BackgroundsSighan(int sig, void *prm __UNUSED__)
      case ESIGNAL_CONFIGURE:
 	BackgroundsConfigLoadUser();
 	BackgroundsCheckDups();
+	StartupBackgroundsDestroy();
 	break;
 
      case ESIGNAL_START:
@@ -1377,6 +1388,7 @@ BackgroundsSighan(int sig, void *prm __UNUSED__)
      }
 }
 
+#if ENABLE_DIALOGS
 /*
  * Configuration dialog
  */
@@ -1717,6 +1729,10 @@ CB_BGScan(Dialog * d, int val __UNUSED__, void *data __UNUSED__)
    int                 num;
 
    SoundPlay(SOUND_WAIT);
+
+   /* Forcing re-scan should not be necessary but provides the progress bars
+    * so it actually looks like something is going on */
+   Mode.backgrounds.force_scan = 1;
    ScanBackgroundMenu();
 
    num = ecore_list_count(bg_list);
@@ -2228,6 +2244,8 @@ const DialogDef     DlgBackground = {
    DLG_OAC, CB_ConfigureBG,
 };
 
+#endif /* ENABLE_DIALOGS */
+
 /*
  * IPC functions
  */
