@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -33,6 +33,7 @@
 #include "iclass.h"
 #include "snaps.h"
 #include "tclass.h"
+#include "timers.h"
 #include "tooltips.h"
 #include "windowmatch.h"
 #include "xwin.h"
@@ -939,15 +940,46 @@ BorderCheckState(EWin * ewin, XEvent * ev)
      }
 }
 
+static int
+_BorderAutoshadeTimeout(void *data)
+{
+   EWin               *ewin = (EWin *) data;
+
+   if (!EwinFindByPtr(ewin))	/* Check, window may be gone */
+      return 0;
+
+   ewin->timer = NULL;
+   EwinOpShade(ewin, OPSRC_USER, 1);
+
+   return 0;
+}
+
 static void
 BorderFrameHandleEvents(Win win __UNUSED__, XEvent * ev, void *prm)
 {
    EWin               *ewin = (EWin *) prm;
+   int                 x, y;
 
    switch (ev->type)
      {
      case EnterNotify:
+	if (ewin->props.autoshade)
+	  {
+	     EwinOpShade(ewin, OPSRC_USER, 0);
+	  }
+	if (ewin->border->aclass)
+	   ActionclassEvent(ewin->border->aclass, ev, ewin);
+	break;
      case LeaveNotify:
+	if (ewin->props.autoshade && !ewin->state.shaded)
+	  {
+	     EQueryPointer(EoGetWin(ewin), &x, &y, NULL, NULL);
+	     if (x >= 4 && x < EoGetW(ewin) - 4 &&
+		 y >= 4 && y < EoGetH(ewin) - 4)
+		break;
+	     TIMER_DEL(ewin->timer);
+	     TIMER_ADD(ewin->timer, .5, _BorderAutoshadeTimeout, ewin);
+	  }
 	if (ewin->border->aclass)
 	   ActionclassEvent(ewin->border->aclass, ev, ewin);
 	break;
@@ -1190,7 +1222,7 @@ BorderConfigLoad(FILE * fs)
 	  case BORDER_BOTTOM:
 	     b->border.bottom = i2;
 	     break;
-	  case SHADEDIR:
+	  case BORDER_SHADEDIR:
 	     b->shadedir = i2;
 	     break;
 	  case BORDER_CHANGES_SHAPE:
