@@ -83,8 +83,6 @@ struct _ewinbit {
 
 /* borders.c */
 Border             *BorderFind(const char *name);
-Border             *BorderAlloc(const char *name);
-void                BorderFree(Border * b);
 const char         *BorderGetName(const Border * b);
 int                 BorderConfigLoad(FILE * fs);
 void                EwinBorderSelect(EWin * ewin);
@@ -94,8 +92,8 @@ void                EwinBorderDraw(EWin * ewin, int do_shape, int do_paint);
 void                EwinBorderCalcSizes(EWin * ewin, int propagate);
 void                EwinBorderMinShadeSize(EWin * ewin, int *mw, int *mh);
 void                EwinBorderUpdateInfo(EWin * ewin);
-void                EwinSetBorder(EWin * ewin, const Border * b, int apply);
-void                EwinSetBorderByName(EWin * ewin, const char *name);
+void                EwinBorderChange(EWin * ewin, const Border * b, int normal);
+void                EwinBorderSetInitially(EWin * ewin, const char *name);
 int                 BorderWinpartIndex(EWin * ewin, Win win);
 void                BorderCheckState(EWin * ewin, XEvent * ev);
 Border             *BorderCreateFiller(int left, int right, int top,
@@ -103,6 +101,5 @@ Border             *BorderCreateFiller(int left, int right, int top,
 void                BordersForeach(void (*func) (Border * b, void *data),
 				   void *data);
 Border            **BordersGetList(int *pnum);
-void                BordersSetupFallback(void);
 
 #endif /* _BORDERS_H_ */
