@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -1557,6 +1557,8 @@ SetNewAreaSize(int ax, int ay)
      }
    if (b >= ay)
       DeskCurrentGotoArea(a, ay - 1);
+
+   autosave();
 }
 
 static void
@@ -1721,7 +1723,8 @@ DeskDragStart(int desk)
 {
    Desk               *dsk;
 
-   dsk = _DeskGet(desk);
+   if (!(dsk = DeskGet(desk)))
+      return;
 
    desks.drag_x0 = Mode.events.cx - EoGetX(dsk);
    desks.drag_y0 = Mode.events.cy - EoGetY(dsk);
@@ -2140,6 +2143,7 @@ DesksSighan(int sig, void *prm __UNUSED__)
      }
 }
 
+#if ENABLE_DIALOGS
 /*
  * Dialogs
  */
@@ -2154,26 +2158,25 @@ static int          tmp_dragdir;
 static void
 CB_ConfigureDesktops(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 {
-   if (val < 2)
-     {
-	ChangeNumberOfDesktops(tmp_desktops);
-	Conf.desks.slidein = tmp_desktop_slide;
-	Conf.desks.slidespeed = tmp_desktop_slide_speed;
-	Conf.desks.desks_wraparound = tmp_desktop_wraparound;
+   if (val >= 2)
+      return;
 
-	if ((Conf.desks.dragdir != tmp_dragdir) ||
-	    ((tmp_dragbar) && (Conf.desks.dragbar_width < 1)) ||
-	    ((!tmp_dragbar) && (Conf.desks.dragbar_width > 0)))
-	  {
-	     if (tmp_dragbar)
-		Conf.desks.dragbar_width = 16;
-	     else
-		Conf.desks.dragbar_width = 0;
-	     Conf.desks.dragdir = tmp_dragdir;
-	     DesksControlsRefresh();
-	  }
+   ChangeNumberOfDesktops(tmp_desktops);
+   Conf.desks.slidein = tmp_desktop_slide;
+   Conf.desks.slidespeed = tmp_desktop_slide_speed;
+   Conf.desks.desks_wraparound = tmp_desktop_wraparound;
+
+   if ((Conf.desks.dragdir != tmp_dragdir) ||
+       ((tmp_dragbar) && (Conf.desks.dragbar_width < 1)) ||
+       ((!tmp_dragbar) && (Conf.desks.dragbar_width > 0)))
+     {
+	if (tmp_dragbar)
+	   Conf.desks.dragbar_width = 16;
+	else
+	   Conf.desks.dragbar_width = 0;
+	Conf.desks.dragdir = tmp_dragdir;
+	DesksControlsRefresh();
      }
-   autosave();
 }
 
 static void
@@ -2393,16 +2396,15 @@ static char         tmp_area_wraparound;
 static void
 CB_ConfigureAreas(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 {
-   if (val < 2)
-     {
-	SetNewAreaSize(tmp_area_x, tmp_area_y);
-	Conf.desks.areas_wraparound = tmp_area_wraparound;
-	Conf.desks.edge_flip_mode = tmp_edge_flip;
-	if (tmp_edge_resist < 1)
-	   tmp_edge_resist = 1;
-	Conf.desks.edge_flip_resistance = tmp_edge_resist;
-     }
-   autosave();
+   if (val >= 2)
+      return;
+
+   SetNewAreaSize(tmp_area_x, tmp_area_y);
+   Conf.desks.areas_wraparound = tmp_area_wraparound;
+   Conf.desks.edge_flip_mode = tmp_edge_flip;
+   if (tmp_edge_resist < 1)
+      tmp_edge_resist = 1;
+   Conf.desks.edge_flip_resistance = tmp_edge_resist;
 }
 
 static void
@@ -2552,6 +2554,7 @@ const DialogDef     DlgAreas = {
    _DlgFillAreas,
    DLG_OAC, CB_ConfigureAreas,
 };
+#endif /* ENABLE_DIALOGS */
 
 /*
  * IPC functions
@@ -2669,13 +2672,6 @@ DesksIpcDesk(const char *params)
 	   desk = atoi(prm);
 	DeskOpDrag(desk);
      }
-   else if (!strcmp(cmd, "dragbar"))
-     {
-	if (!strncmp(prm, "dir", 3))
-	   DeskDragdirSet(p);
-	else if (!strncmp(prm, "ord", 3))
-	   DeskDragbarOrderSet(p);
-     }
    else if (!strcmp(cmd, "clear"))
      {
 	EwinsShowDesktop(!Mode.showing_desktop);
@@ -2753,8 +2749,6 @@ static const IpcItem DesksIpcArray[] = {
     "  desk this            Goto this desktop\n"
     "  desk lower <d>       Lower desktop\n"
     "  desk raise <d>       Raise desktop\n"
-    "  desk dragbar pos     Set dragbar position\n"
-    "  desk dragbar order   Set dragbar button order\n"
     "  desk arrange         Arrange windows on desktop\"\n"
     "  desk clear           \"Show Desktop\"\n"}
    ,
