@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -22,6 +22,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 #include "E.h"
+#if ENABLE_DIALOGS
 #include "dialog.h"
 #include "e16-ecore_list.h"
 #include "eimage.h"
@@ -2399,3 +2400,5 @@ FindADialog(void)
 
    return n;
 }
+
+#endif /* ENABLE_DIALOGS */
