@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2007 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -24,6 +24,10 @@
 #ifndef _DIALOG_H_
 #define _DIALOG_H_
 
+#include "config.h"
+
+#if ENABLE_DIALOGS
+
 /* Dialog items */
 #define DITEM_NONE         0
 #define DITEM_BUTTON       1
@@ -155,4 +159,6 @@ void                DialogCallbackClose(Dialog * d, int val, void *data);
 
 void                DialogsInit(void);
 
+#endif /* ENABLE_DIALOGS */
+
 #endif /* _DIALOG_H_ */
