@@ -48,6 +48,14 @@ EImageInit(void)
    imlib_context_set_dither(1);
 }
 
+void
+EImageExit(int quit __UNUSED__)
+{
+#if HAVE_IMLIB_CONTEXT_DISCONNECT_DISPLAY
+   imlib_context_disconnect_display();
+#endif
+}
+
 int
 EImageSetCacheSize(int size)
 {
@@ -301,7 +309,9 @@ EImageTile(EImage * im, EImage * tile, int flags, int tw, int th,
 	tim = imlib_create_image(tw, th);
 	imlib_context_set_image(tim);
 	imlib_context_set_blend(0);
+	imlib_context_set_anti_alias(1);
 	imlib_blend_image_onto_image(tile, 0, 0, 0, sw, sh, 0, 0, tw, th);
+	imlib_context_set_anti_alias(0);
      }
    imlib_context_set_image(im);
 
@@ -465,7 +475,7 @@ EImageApplyToWin(EImage * im, Win win, int flags, int w, int h)
    EImageRenderPixmaps(im, win, flags, &pmap, &mask, w, h);
    ESetWindowBackgroundPixmap(win, pmap);
    if ((mask != None) || (mask == None && WinIsShaped(win)))
-      EShapeCombineMask(win, ShapeBounding, 0, 0, mask, ShapeSet);
+      EShapeSetMask(win, 0, 0, mask);
    EImagePixmapsFree(pmap, mask);
    EClearWindow(win);
 }
@@ -566,6 +576,7 @@ ScaleTile(Win wsrc, Drawable src, Win wdst, Pixmap dst,
    imlib_free_image();
 }
 
+#if 0				/* Unused */
 void
 EDrawableDumpImage(Drawable draw, const char *txt)
 {
@@ -587,6 +598,7 @@ EDrawableDumpImage(Drawable draw, const char *txt)
    imlib_save_image(buf);
    imlib_free_image_and_decache();
 }
+#endif
 
 void
 FreePmapMask(PmapMask * pmm)
