@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -34,6 +34,7 @@
 #include "iclass.h"		/* FIXME - Should not be here */
 #include "screen.h"
 #include "snaps.h"
+#include "timers.h"
 #include "xwin.h"
 
 static const WinOp  winops[] = {
@@ -81,6 +82,7 @@ static const WinOp  winops[] = {
    {"never_use_area", 0, 1, 1, EWIN_OP_NEVER_USE_AREA},
    {"no_button_grabs", 0, 1, 1, EWIN_OP_NO_BUTTON_GRABS},
    {"skiplists", 4, 1, 1, EWIN_OP_SKIP_LISTS},
+   {"autoshade", 0, 1, 1, EWIN_OP_AUTOSHADE},
 
    {"no_app_focus", 0, 1, 1, EWIN_OP_INH_APP_FOCUS},
    {"no_app_move", 0, 1, 1, EWIN_OP_INH_APP_MOVE},
@@ -688,10 +690,11 @@ EwinDeIconify(EWin * ewin)
 static void
 EwinUnStick(EWin * ewin)
 {
-
-   if (!ewin)
+   if (!EoIsSticky(ewin))
       return;
 
+   SoundPlay(SOUND_WINDOW_UNSTICK);
+
    EoSetSticky(ewin, 0);
    EwinMoveToDesktopAt(ewin, DesksGetCurrent(), EoGetX(ewin), EoGetY(ewin));
    EwinBorderUpdateState(ewin);
@@ -706,9 +709,11 @@ EwinStick(EWin * ewin)
 {
    int                 x, y, dx, dy;
 
-   if (!ewin)
+   if (EoIsSticky(ewin))
       return;
 
+   SoundPlay(SOUND_WINDOW_STICK);
+
    /* Avoid "losing" windows made sticky while not in the current viewport */
    dx = EoGetW(ewin) / 2;
    dy = EoGetH(ewin) / 2;
@@ -735,7 +740,7 @@ EwinInstantShade(EWin * ewin, int force)
 {
    XSetWindowAttributes att;
    int                 x, y, w, h;
-   int                 b, d;
+   int                 minw, minh;
 
    if ((ewin->border->border.left == 0) && (ewin->border->border.right == 0)
        && (ewin->border->border.top == 0) && (ewin->border->border.bottom == 0))
@@ -750,39 +755,34 @@ EwinInstantShade(EWin * ewin, int force)
    w = EoGetW(ewin);
    h = EoGetH(ewin);
 
+   EwinBorderMinShadeSize(ewin, &minw, &minh);
+
    switch (ewin->border->shadedir)
      {
      default:
      case 0:
 	att.win_gravity = EastGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &b, &d);
-	w = b;
+	w = minw;
 	break;
      case 1:
 	att.win_gravity = WestGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &b, &d);
 	if (!Mode.wm.startup)
-	   x = x + w - b;
-	w = b;
+	   x = x + w - minw;
+	w = minw;
 	break;
      case 2:
 	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &b, &d);
-	h = d;
+	h = minh;
 	break;
      case 3:
 	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &b, &d);
 	if (!Mode.wm.startup)
-	   y = y + h - d;
-	h = d;
+	   y = y + h - minh;
+	h = minh;
 	break;
      }
 
+   EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
    ewin->state.shaded = 2;
    EoMoveResize(ewin, x, y, w, h);
    EMoveResizeWindow(ewin->win_container, -30, -30, 1, 1);
@@ -809,27 +809,19 @@ EwinInstantUnShade(EWin * ewin)
      {
      default:
      case 0:
-	att.win_gravity = EastGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
 	w = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
 	break;
      case 1:
-	att.win_gravity = WestGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
 	w = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
 	x = x + EoGetW(ewin) - w;
 	break;
      case 2:
-	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
 	h = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
 	break;
      case 3:
-	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
 	h = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
 	y = y + EoGetH(ewin) - h;
@@ -850,34 +842,37 @@ EwinInstantUnShade(EWin * ewin)
     ewin->update.shape = 1; \
   } while (0)
 
-void
-EwinShade(EWin * ewin)
-{
-   XSetWindowAttributes att;
+typedef struct {
    int                 x, y, w, h;
-   int                 k, speed, a, b, c, ww, hh;
+} _xywh;
+typedef struct {
+   EWin               *ewin;
+   int                 k, dk;
+   _xywh               start;
+   _xywh               final;
+   int                 a, b, c, d;
+} _ewin_shade_data;
 
-   if ((ewin->border->border.left == 0) && (ewin->border->border.right == 0)
-       && (ewin->border->border.top == 0) && (ewin->border->border.bottom == 0))
-      return;
-   if (GetZoomEWin() == ewin)
-      return;
-   if (ewin->state.shaded || ewin->state.iconified)
-      return;
-   if ((ewin->border) && (!strcmp(ewin->border->name, "BORDERLESS")))
-      return;
+static void
+_EwinShadeStart(_ewin_shade_data * esd)
+{
+   EWin               *ewin = esd->ewin;
+   int                 minw, minh;
+   XSetWindowAttributes att;
 
-   DeskRestack(EoGetDesk(ewin));	/* Do any pending stacking ops now */
+   esd->k = 0;
+   esd->dk = 1024 * Conf.shading.speed * Conf.animation.step / 1000000;
 
-   speed = Conf.shading.speed;
-
-   x = EoGetX(ewin);
-   y = EoGetY(ewin);
-   w = EoGetW(ewin);
-   h = EoGetH(ewin);
+   esd->start.x = EoGetX(ewin);
+   esd->start.y = EoGetY(ewin);
+   esd->start.w = EoGetW(ewin);
+   esd->start.h = EoGetH(ewin);
+   esd->final = esd->start;
 
    ewin->state.shading = 1;
 
+   EwinBorderMinShadeSize(ewin, &minw, &minh);
+
 #if 0
    Eprintf("EwinShade-B %d\n", ewin->border->shadedir);
    EGrabServer();
@@ -888,134 +883,43 @@ EwinShade(EWin * ewin)
      default:
      case 0:
 	att.win_gravity = EastGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &b, &c);
-	a = w;
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  w = ((a * (1024 - k)) + (b * k)) >> 10;
-		  if (w < 1)
-		     w = 1;
-		  ww = w - ewin->border->border.left -
-		     ewin->border->border.right;
-		  if (ww < 1)
-		     ww = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ww, ewin->client.h);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, ww - ewin->client.w, 0);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, x, y, b, h);
+	esd->a = esd->start.w;
+	esd->b = minw;
+	esd->final.w = esd->b;
 	break;
      case 1:
 	att.win_gravity = WestGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &b, &c);
-	a = w;
-	c = x + w;
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  w = ((a * (1024 - k)) + (b * k)) >> 10;
-		  if (w < 1)
-		     w = 1;
-		  x = c - w;
-		  ww = w - ewin->border->border.left -
-		     ewin->border->border.right;
-		  if (ww < 1)
-		     ww = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ww, ewin->client.h);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, 0, 0);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, c - b, y, b, h);
+	esd->a = esd->start.w;
+	esd->b = minw;
+	esd->c = esd->start.x + esd->start.w;
+	esd->final.x = esd->c - esd->b;
+	esd->final.w = esd->b;
 	break;
      case 2:
 	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &c, &b);
-	a = h;
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  h = ((a * (1024 - k)) + (b * k)) >> 10;
-		  if (h < 1)
-		     h = 1;
-		  hh = h - ewin->border->border.top -
-		     ewin->border->border.bottom;
-		  if (hh < 1)
-		     hh = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ewin->client.w, hh);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, 0, hh - ewin->client.h);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, x, y, w, b);
+	esd->a = esd->start.h;
+	esd->b = minh;
+	esd->final.h = esd->b;
 	break;
      case 3:
 	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	EwinBorderMinShadeSize(ewin, &c, &b);
-	a = h;
-	c = y + h;
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  h = ((a * (1024 - k)) + (b * k)) >> 10;
-		  if (h < 1)
-		     h = 1;
-		  y = c - h;
-		  hh = h - ewin->border->border.top -
-		     ewin->border->border.bottom;
-		  if (hh < 1)
-		     hh = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ewin->client.w, hh);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, 0, hh - ewin->client.h);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, x, c - b, w, b);
+	esd->a = esd->start.h;
+	esd->b = minh;
+	esd->c = esd->start.y + esd->start.h;
+	esd->final.y = esd->c - esd->b;
+	esd->final.h = esd->b;
 	break;
      }
 
+   EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
+}
+
+static void
+_EwinShadeEnd(_ewin_shade_data * esd)
+{
+   EWin               *ewin = esd->ewin;
+
+   EoMoveResize(ewin, esd->final.x, esd->final.y, esd->final.w, esd->final.h);
    ewin->state.shaded = 2;
    EMoveResizeWindow(ewin->win_container, -30, -30, 1, 1);
    if (ewin->state.shaped)
@@ -1033,30 +937,148 @@ EwinShade(EWin * ewin)
 
    EwinStateUpdate(ewin);
    HintsSetWindowState(ewin);
+   SnapshotEwinUpdate(ewin, SNAP_USE_SHADED);
+
+   Efree(esd);
+}
+
+static int
+_EwinShadeRun(void *data)
+{
+   _ewin_shade_data   *esd = (_ewin_shade_data *) data;
+   EWin               *ewin = esd->ewin;
+   int                 k, x, y, w, h, ww, hh, cow, coh, shx, shy;
+
+   if (!EwinFindByPtr(ewin))	/* Check, window may be gone */
+     {
+	Efree(esd);
+	return 0;
+     }
+
+   k = esd->k;
+
+   x = esd->start.x;
+   y = esd->start.y;
+   w = esd->start.w;
+   h = esd->start.h;
+
+   cow = ewin->client.w;
+   coh = ewin->client.h;
+
+   shx = shy = 0;
+
+   switch (ewin->border->shadedir)
+     {
+     default:
+     case 0:
+	w = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	if (w < 1)
+	   w = 1;
+	ww = w - ewin->border->border.left - ewin->border->border.right;
+	if (ww < 1)
+	   ww = 1;
+	cow = ww;
+	shx = ww - ewin->client.w;
+	break;
+     case 1:
+	w = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	if (w < 1)
+	   w = 1;
+	x = esd->c - w;
+	ww = w - ewin->border->border.left - ewin->border->border.right;
+	if (ww < 1)
+	   ww = 1;
+	cow = ww;
+	break;
+     case 2:
+	h = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	if (h < 1)
+	   h = 1;
+	hh = h - ewin->border->border.top - ewin->border->border.bottom;
+	if (hh < 1)
+	   hh = 1;
+	coh = hh;
+	shy = hh - ewin->client.h;
+	break;
+     case 3:
+	h = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	if (h < 1)
+	   h = 1;
+	y = esd->c - h;
+	hh = h - ewin->border->border.top - ewin->border->border.bottom;
+	if (hh < 1)
+	   hh = 1;
+	coh = hh;
+	shy = hh - ewin->client.h;
+	break;
+     }
+   EMoveResizeWindow(ewin->win_container,
+		     ewin->border->border.left,
+		     ewin->border->border.top, cow, coh);
+   if (ewin->state.shaped)
+      _EWIN_ADJUST_SHAPE(ewin, shx, shy);
+   EoMoveResize(ewin, x, y, w, h);
+   EwinBorderCalcSizes(ewin, 1);
+
+   esd->k = k += esd->dk;
+   if (k < 1024)
+      return 1;
+
+   _EwinShadeEnd(esd);
+   return 0;
 }
 
 void
-EwinUnShade(EWin * ewin)
+EwinShade(EWin * ewin)
 {
-   XSetWindowAttributes att;
-   int                 x, y, w, h;
-   int                 k, speed, a, b, c, ww, hh;
+   _ewin_shade_data   *esd;
 
+   if ((ewin->border->border.left == 0) && (ewin->border->border.right == 0) &&
+       (ewin->border->border.top == 0) && (ewin->border->border.bottom == 0))
+      return;
    if (GetZoomEWin() == ewin)
       return;
-   if (!ewin->state.shaded || ewin->state.iconified)
+   if (ewin->state.shaded || ewin->state.shading || ewin->state.iconified)
       return;
+   if ((ewin->border) && (!strcmp(ewin->border->name, "BORDERLESS")))
+      return;
+
+   SoundPlay(SOUND_SHADE);
 
    DeskRestack(EoGetDesk(ewin));	/* Do any pending stacking ops now */
 
-   speed = Conf.shading.speed;
+   esd = EMALLOC(_ewin_shade_data, 1);
+   esd->ewin = ewin;
+   _EwinShadeStart(esd);
+   if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
+      AnimatorAdd(_EwinShadeRun, esd);
+   else
+      _EwinShadeEnd(esd);
+}
 
-   x = EoGetX(ewin);
-   y = EoGetY(ewin);
-   w = EoGetW(ewin);
-   h = EoGetH(ewin);
+static void
+_EwinUnshadeStart(_ewin_shade_data * esd)
+{
+   EWin               *ewin = esd->ewin;
+   int                 cow, coh, clx, cly;
+   XSetWindowAttributes att;
+
+   esd->k = 0;
+   esd->dk = 1024 * Conf.shading.speed * Conf.animation.step / 1000000;
+
+   esd->start.x = EoGetX(ewin);
+   esd->start.y = EoGetY(ewin);
+   esd->start.w = EoGetW(ewin);
+   esd->start.h = EoGetH(ewin);
+   esd->final = esd->start;
 
    ewin->state.shading = 1;
+   ewin->state.shaded = 0;
+
+   cow = ewin->client.w;
+   coh = ewin->client.h;
+
+   clx = cly = 0;
 
 #if 0
    Eprintf("EwinUnShade-B %d\n", ewin->border->shadedir);
@@ -1068,158 +1090,62 @@ EwinUnShade(EWin * ewin)
      default:
      case 0:
 	att.win_gravity = EastGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	a = ewin->border->border.left + ewin->border->border.right;
-	b = ewin->client.w + a;
-	ewin->state.shaded = 0;
-	EMoveResizeWindow(ewin->win_container,
-			  ewin->border->border.left, ewin->border->border.top,
-			  1, ewin->client.h);
-	EWindowSync(EwinGetClientWin(ewin));	/* Gravity - recache */
-	EMoveResizeWindow(EwinGetClientWin(ewin), -ewin->client.w, 0,
-			  ewin->client.w, ewin->client.h);
-	EMapWindow(EwinGetClientWin(ewin));
-	EMapWindow(ewin->win_container);
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  w = ((a * (1024 - k)) + (b * k)) >> 10;
-		  ww = w - a;
-		  if (ww <= 0)
-		     ww = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ww, ewin->client.h);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, ww - ewin->client.w, 0);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, x, y, b, h);
+	esd->a = ewin->border->border.left + ewin->border->border.right;
+	esd->b = ewin->client.w + esd->a;
+	esd->c = 0;		/* Not used */
+	esd->final.w = esd->b;
+	cow = 1;
+	clx = -ewin->client.w;
 	break;
      case 1:
 	att.win_gravity = WestGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	a = ewin->border->border.left + ewin->border->border.right;
-	b = ewin->client.w + a;
-	c = x + w;		/* NB! w != a is possible */
-	ewin->state.shaded = 0;
-	EMoveResizeWindow(ewin->win_container,
-			  ewin->border->border.left, ewin->border->border.top,
-			  1, ewin->client.h);
-	EWindowSync(EwinGetClientWin(ewin));	/* Gravity - recache */
-	EMoveResizeWindow(EwinGetClientWin(ewin), 0, 0, ewin->client.w,
-			  ewin->client.h);
-	EMapWindow(EwinGetClientWin(ewin));
-	EMapWindow(ewin->win_container);
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  w = ((a * (1024 - k)) + (b * k)) >> 10;
-		  x = c - w;
-		  ww = w - a;
-		  if (ww <= 0)
-		     ww = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ww, ewin->client.h);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, 0, 0);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, c - b, y, b, h);
+	esd->a = ewin->border->border.left + ewin->border->border.right;
+	esd->b = ewin->client.w + esd->a;
+	esd->c = esd->start.x + esd->start.w;	/* NB! w != a is possible */
+	esd->final.x = esd->c - esd->b;
+	esd->final.w = esd->b;
+	cow = 1;
 	break;
      case 2:
 	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	a = ewin->border->border.top + ewin->border->border.bottom;
-	b = ewin->client.h + a;
-	ewin->state.shaded = 0;
-	EMoveResizeWindow(ewin->win_container,
-			  ewin->border->border.left, ewin->border->border.top,
-			  ewin->client.w, 1);
-	EWindowSync(EwinGetClientWin(ewin));	/* Gravity - recache */
-	EMoveResizeWindow(EwinGetClientWin(ewin), 0, 1 - ewin->client.h,
-			  ewin->client.w, ewin->client.h);
-	EMapWindow(EwinGetClientWin(ewin));
-	EMapWindow(ewin->win_container);
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  h = ((a * (1024 - k)) + (b * k)) >> 10;
-		  hh = h - a;
-		  if (hh <= 0)
-		     hh = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ewin->client.w, hh);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, 0, hh - ewin->client.h);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, x, y, w, b);
+	esd->a = ewin->border->border.top + ewin->border->border.bottom;
+	esd->b = ewin->client.h + esd->a;
+	esd->c = 0;		/* Not used */
+	esd->final.h = esd->b;
+	coh = 1;
+	cly = 1 - ewin->client.h;
 	break;
      case 3:
 	att.win_gravity = SouthGravity;
-	EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
-	a = ewin->border->border.top + ewin->border->border.bottom;
-	b = ewin->client.h + a;
-	c = y + h;		/* NB! h != a is possible */
-	ewin->state.shaded = 0;
-	EMoveResizeWindow(ewin->win_container,
-			  ewin->border->border.left, ewin->border->border.top,
-			  ewin->client.w, 1);
-	EWindowSync(EwinGetClientWin(ewin));	/* Gravity - recache */
-	EMoveResizeWindow(EwinGetClientWin(ewin), 0, 1 - ewin->client.h,
-			  ewin->client.w, ewin->client.h);
-	EMapWindow(EwinGetClientWin(ewin));
-	EMapWindow(ewin->win_container);
-	if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
-	  {
-	     ETimedLoopInit(0, 1024, speed);
-	     for (k = 0; k < 1024;)
-	       {
-		  h = ((a * (1024 - k)) + (b * k)) >> 10;
-		  y = c - h;
-		  hh = h - a;
-		  if (hh <= 0)
-		     hh = 1;
-		  EMoveResizeWindow(ewin->win_container,
-				    ewin->border->border.left,
-				    ewin->border->border.top,
-				    ewin->client.w, hh);
-		  if (ewin->state.shaped)
-		     _EWIN_ADJUST_SHAPE(ewin, 0, hh - ewin->client.h);
-		  EoMoveResize(ewin, x, y, w, h);
-		  EwinBorderCalcSizes(ewin, 1);
-
-		  k = ETimedLoopNext();
-	       }
-	  }
-	EoMoveResize(ewin, x, c - b, w, b);
+	esd->a = ewin->border->border.top + ewin->border->border.bottom;
+	esd->b = ewin->client.h + esd->a;
+	esd->c = esd->start.y + esd->start.h;	/* NB! h != a is possible */
+	esd->final.y = esd->c - esd->b;
+	esd->final.h = esd->b;
+	coh = 1;
+	cly = 1 - ewin->client.h;
 	break;
      }
 
+   EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
+   EMoveResizeWindow(ewin->win_container,
+		     ewin->border->border.left, ewin->border->border.top,
+		     cow, coh);
+   EWindowSync(EwinGetClientWin(ewin));	/* Gravity - recache */
+   EMoveResizeWindow(EwinGetClientWin(ewin), clx, cly,
+		     ewin->client.w, ewin->client.h);
+   EMapWindow(EwinGetClientWin(ewin));
+   EMapWindow(ewin->win_container);
+}
+
+static void
+_EwinUnshadeEnd(_ewin_shade_data * esd)
+{
+   EWin               *ewin = esd->ewin;
+   XSetWindowAttributes att;
+
+   EoMoveResize(ewin, esd->final.x, esd->final.y, esd->final.w, esd->final.h);
+
    /* Reset gravity */
    att.win_gravity = NorthWestGravity;
    EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
@@ -1244,6 +1170,111 @@ EwinUnShade(EWin * ewin)
 
    EwinStateUpdate(ewin);
    HintsSetWindowState(ewin);
+   SnapshotEwinUpdate(ewin, SNAP_USE_SHADED);
+
+   Efree(esd);
+}
+
+static int
+_EwinUnshadeRun(void *data)
+{
+   _ewin_shade_data   *esd = (_ewin_shade_data *) data;
+   EWin               *ewin = esd->ewin;
+   int                 k, x, y, w, h, ww, hh, cow, coh, shx, shy;
+
+   if (!EwinFindByPtr(ewin))	/* Check, window may be gone */
+     {
+	Efree(esd);
+	return 0;
+     }
+
+   k = esd->k;
+
+   x = esd->start.x;
+   y = esd->start.y;
+   w = esd->start.w;
+   h = esd->start.h;
+
+   cow = ewin->client.w;
+   coh = ewin->client.h;
+
+   shx = shy = 0;
+
+   switch (ewin->border->shadedir)
+     {
+     default:
+     case 0:
+	w = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	ww = w - esd->a;
+	if (ww <= 0)
+	   ww = 1;
+	cow = ww;
+	shx = ww - ewin->client.w;
+	break;
+     case 1:
+	w = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	x = esd->c - w;
+	ww = w - esd->a;
+	if (ww <= 0)
+	   ww = 1;
+	cow = ww;
+	break;
+     case 2:
+	h = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	hh = h - esd->a;
+	if (hh <= 0)
+	   hh = 1;
+	coh = hh;
+	shy = hh - ewin->client.h;
+	break;
+     case 3:
+	h = ((esd->a * (1024 - k)) + (esd->b * k)) >> 10;
+	y = esd->c - h;
+	hh = h - esd->a;
+	if (hh <= 0)
+	   hh = 1;
+	coh = hh;
+	shy = hh - ewin->client.h;
+	break;
+     }
+   EMoveResizeWindow(ewin->win_container,
+		     ewin->border->border.left,
+		     ewin->border->border.top, cow, coh);
+   if (ewin->state.shaped)
+      _EWIN_ADJUST_SHAPE(ewin, shx, shy);
+   EoMoveResize(ewin, x, y, w, h);
+   EwinBorderCalcSizes(ewin, 1);
+
+   esd->k = k += esd->dk;
+   if (k < 1024)
+      return 1;
+
+   _EwinUnshadeEnd(esd);
+   return 0;
+}
+
+void
+EwinUnShade(EWin * ewin)
+{
+   _ewin_shade_data   *esd;
+
+   if (GetZoomEWin() == ewin)
+      return;
+   TIMER_DEL(ewin->timer);
+   if (!ewin->state.shaded || ewin->state.shading || ewin->state.iconified)
+      return;
+
+   SoundPlay(SOUND_UNSHADE);
+
+   DeskRestack(EoGetDesk(ewin));	/* Do any pending stacking ops now */
+
+   esd = EMALLOC(_ewin_shade_data, 1);
+   esd->ewin = ewin;
+   _EwinUnshadeStart(esd);
+   if ((Conf.shading.animate) || (ewin->type == EWIN_TYPE_MENU))
+      AnimatorAdd(_EwinUnshadeRun, esd);
+   else
+      _EwinUnshadeEnd(esd);
 }
 
 void
@@ -1436,7 +1467,7 @@ EwinOpRaise(EWin * ewin, int source __UNUSED__)
    int                 i, num;
 
    SoundPlay(SOUND_RAISE);
-   gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_RAISE,
+   gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_STACKING,
 				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
       EwinRaise(gwins[i]);
@@ -1450,98 +1481,27 @@ EwinOpLower(EWin * ewin, int source __UNUSED__)
    int                 i, num;
 
    SoundPlay(SOUND_LOWER);
-   gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_LOWER,
+   gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_STACKING,
 				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
       EwinLower(gwins[i]);
    Efree(gwins);
 }
 
-#if 0				/* Unused */
-static int
-FindEwinInList(EWin * ewin, EWin ** gwins, int num)
-{
-   int                 i;
-
-   if (ewin && gwins)
-     {
-	for (i = 0; i < num; i++)
-	  {
-	     if (ewin == gwins[i])
-		return 1;
-	  }
-     }
-   return 0;
-}
-
-void
-EwinOpRaiseLower(EWin * ewin)
-{
-   EWin              **gwins, *const *lst;
-   int                 gnum, j, raise = 0;
-   int                 i, num;
-
-   lst = EwinListGetForDesk(&num, EoGetDesk(ewin));
-   gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_RAISE_LOWER,
-				      Mode.nogroup, &gnum);
-   for (j = 0; j < gnum; j++)
-     {
-	ewin = gwins[j];
-	for (i = 0; i < num - 1; i++)
-	  {
-	     if (EoGetLayer(lst[i]) == EoGetLayer(ewin) &&
-		 (lst[i] == ewin || !FindEwinInList(lst[i], gwins, gnum)))
-	       {
-		  if (lst[i] != ewin)
-		     raise = 1;
-
-		  j = gnum;
-		  break;
-	       }
-	  }
-     }
-
-   if (!raise)
-     {
-	SoundPlay(SOUND_LOWER);
-	for (j = 0; j < gnum; j++)
-	   EwinLower(gwins[j]);
-     }
-   else
-     {
-	SoundPlay(SOUND_RAISE);
-	for (j = 0; j < gnum; j++)
-	   EwinRaise(gwins[j]);
-     }
-
-   Efree(gwins);
-}
-#endif
-
 void
 EwinOpStick(EWin * ewin, int source __UNUSED__, int on)
 {
    EWin              **gwins = NULL;
-   Group              *curr_group = NULL;
    int                 i, num;
 
    gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_STICK,
 				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
      {
-	curr_group = EwinsInGroup(ewin, gwins[i]);
-	if (EoIsSticky(gwins[i])
-	    && ((curr_group && !curr_group->cfg.mirror) || !on))
-	  {
-	     SoundPlay(SOUND_WINDOW_UNSTICK);
-	     EwinUnStick(gwins[i]);
-	  }
-	else if (!EoIsSticky(gwins[i])
-		 && ((curr_group && !curr_group->cfg.mirror) || on))
-	  {
-	     SoundPlay(SOUND_WINDOW_STICK);
-	     EwinStick(gwins[i]);
-	  }
+	if (on)
+	   EwinStick(gwins[i]);
+	else
+	   EwinUnStick(gwins[i]);
      }
    Efree(gwins);
 }
@@ -1603,26 +1563,17 @@ EwinOpNeverFocus(EWin * ewin, int on)
 void
 EwinOpIconify(EWin * ewin, int source __UNUSED__, int on)
 {
-   Group              *curr_group = NULL;
    EWin              **gwins = NULL;
    int                 i, num;
 
-   gwins =
-      ListWinGroupMembersForEwin(ewin, GROUP_ACTION_ICONIFY, Mode.nogroup,
-				 &num);
+   gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_ICONIFY,
+				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
      {
-	curr_group = EwinsInGroup(ewin, gwins[i]);
-	if (gwins[i]->state.iconified
-	    && ((curr_group && !curr_group->cfg.mirror) || !on))
-	  {
-	     EwinDeIconify(gwins[i]);
-	  }
-	else if (!gwins[i]->state.iconified
-		 && ((curr_group && !curr_group->cfg.mirror) || on))
-	  {
-	     EwinIconify(gwins[i]);
-	  }
+	if (on)
+	   EwinIconify(gwins[i]);
+	else
+	   EwinDeIconify(gwins[i]);
      }
    Efree(gwins);
 }
@@ -1631,27 +1582,16 @@ void
 EwinOpShade(EWin * ewin, int source __UNUSED__, int on)
 {
    EWin              **gwins = NULL;
-   Group              *curr_group = NULL;
    int                 i, num;
 
    gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_SHADE,
 				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
      {
-	curr_group = EwinsInGroup(ewin, gwins[i]);
-	if (gwins[i]->state.shaded
-	    && ((curr_group && !curr_group->cfg.mirror) || !on))
-	  {
-	     SoundPlay(SOUND_UNSHADE);
-	     EwinUnShade(gwins[i]);
-	  }
-	else if (!gwins[i]->state.shaded
-		 && ((curr_group && !curr_group->cfg.mirror) || on))
-	  {
-	     SoundPlay(SOUND_SHADE);
-	     EwinShade(gwins[i]);
-	  }
-	SnapshotEwinUpdate(gwins[i], SNAP_USE_SHADED);
+	if (on)
+	   EwinShade(gwins[i]);
+	else
+	   EwinUnShade(gwins[i]);
      }
    Efree(gwins);
 }
