@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -105,6 +105,7 @@ struct _ewin {
       unsigned            show_coords:1;
       unsigned            maximizing:1;
       unsigned            shading:1;
+      unsigned            in_action:1;
 
       /* Derived state flags. Change only in EwinStateUpdate() */
       unsigned            no_border:1;
@@ -136,6 +137,7 @@ struct _ewin {
       unsigned            skip_winlist:1;
       unsigned            focusclick:1;	/* Click to focus */
       unsigned            no_button_grabs:1;
+      unsigned            autoshade:1;	/* Autoshade on mouse in/out */
       unsigned            no_argb:1;	/* Do not use ARGB frame */
 
       /* Derived from other properties */
@@ -262,6 +264,8 @@ struct _ewin {
 
    void               *data;	/* Data hook for internal windows */
    const EWinOps      *ops;
+
+   Timer              *timer;	/* Autoshade timer */
 };
 
 #define EWIN_STATE_NEW          0	/* New */
@@ -316,6 +320,7 @@ void                ArrangeEwins(const char *params);
 
 /* coords.c */
 void                CoordsShow(EWin * ewin);
+void                CoordsShowOpacity(EWin * ewin);
 void                CoordsHide(void);
 
 /* dock.c */
@@ -449,11 +454,13 @@ void                EwinSyncRequestWait(EWin * ewin);
 #endif
 
 /* moveresize.c */
-int                 ActionMoveStart(EWin * ewin, char constrained, int nogroup);
-int                 ActionResizeStart(EWin * ewin, int hv);
+int                 ActionMoveStart(EWin * ewin, int kbd, int constrained,
+				    int nogroup);
+int                 ActionResizeStart(EWin * ewin, int kbd, int hv);
 
 int                 ActionsSuspend(void);
 int                 ActionsResume(void);
+void                ActionsHandleKey(unsigned int key);
 void                ActionsHandleMotion(void);
 int                 ActionsEnd(EWin * ewin);
 
