@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2008 Kim Woelders
+ * Copyright (C) 2003-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -43,6 +43,7 @@
 #define _NET_WM_MOVERESIZE_MOVE             8
 #define _NET_WM_MOVERESIZE_SIZE_KEYBOARD    9
 #define _NET_WM_MOVERESIZE_MOVE_KEYBOARD   10
+#define _NET_WM_MOVERESIZE_CANCEL          11
 
 /* Window state property change actions */
 #define _NET_WM_STATE_REMOVE    0
@@ -56,10 +57,6 @@
 
 #define OPSRC(src) (((src) == _NET_WM_SOURCE_USER) ? _NET_WM_SOURCE_USER : _NET_WM_SOURCE_APP)
 
-#ifndef ENABLE_HINTS_GNOME
-Atom                _G_WIN_LAUER;
-#endif
-
 /*
  * Set/clear Atom in list
  */
@@ -1028,26 +1025,29 @@ EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
 	  case _NET_WM_MOVERESIZE_SIZE_TOPRIGHT:
 	  case _NET_WM_MOVERESIZE_SIZE_BOTTOMRIGHT:
 	  case _NET_WM_MOVERESIZE_SIZE_BOTTOMLEFT:
-	     ActionResizeStart(ewin, MODE_RESIZE);
+	     ActionResizeStart(ewin, 0, MODE_RESIZE);
 	     break;
 	  case _NET_WM_MOVERESIZE_SIZE_RIGHT:
 	  case _NET_WM_MOVERESIZE_SIZE_LEFT:
-	     ActionResizeStart(ewin, MODE_RESIZE_H);
+	     ActionResizeStart(ewin, 0, MODE_RESIZE_H);
 	     break;
 	  case _NET_WM_MOVERESIZE_SIZE_TOP:
 	  case _NET_WM_MOVERESIZE_SIZE_BOTTOM:
-	     ActionResizeStart(ewin, MODE_RESIZE_V);
+	     ActionResizeStart(ewin, 0, MODE_RESIZE_V);
 	     break;
 
 	  case _NET_WM_MOVERESIZE_MOVE:
-	     ActionMoveStart(ewin, 0, 0);
+	     ActionMoveStart(ewin, 0, 0, 0);
 	     break;
 
 	  case _NET_WM_MOVERESIZE_SIZE_KEYBOARD:
-	     /* doResize(NULL); */
+	     ActionResizeStart(ewin, 1, MODE_RESIZE);
 	     break;
 	  case _NET_WM_MOVERESIZE_MOVE_KEYBOARD:
-	     /* doMove(NULL); */
+	     ActionMoveStart(ewin, 1, 0, 0);
+	     break;
+	  case _NET_WM_MOVERESIZE_CANCEL:
+	     ActionsEnd(ewin);
 	     break;
 	  }
 	return 1;
