@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -517,6 +517,15 @@ FocusNewDesk(void)
    XUngrabKeyboard(disp, CurrentTime);
 }
 
+void
+FocusCheckScreen(void)
+{
+   if (EQueryPointer(NULL, NULL, NULL, NULL, NULL))
+      return;			/* On screen */
+
+   FocusToEWin(NULL, FOCUS_DESK_LEAVE);
+}
+
 static void
 FocusInit(void)
 {
@@ -619,6 +628,7 @@ FocusHandleClick(EWin * ewin, Win win)
      }
 }
 
+#if ENABLE_DIALOGS
 /*      
  * Configuration dialog
  */
@@ -844,6 +854,7 @@ const DialogDef     DlgFocus = {
    _DlgFillFocus,
    DLG_OAC, CB_ConfigureFocus,
 };
+#endif /* ENABLE_DIALOGS */
 
 /*
  * Focus Module
