@@ -139,7 +139,7 @@ IB_Animate_A(char iconify, EWin * ewin, EWin * ibox)
 	XDrawLine(disp, root, gc, x3, y3, x4, y4);
 	XDrawLine(disp, root, gc, x4, y4, x1, y1);
 
-	ESync(ESYNC_ICONIFY);
+	ESync(0);
 	IB_Animate_Sleep(t0, a);
 
 	XDrawLine(disp, root, gc, x1, y1, x2, y2);
@@ -216,7 +216,7 @@ IB_Animate_B(char iconify, EWin * ewin, EWin * ibox)
 	h = (int)(fh + a * (th - fh));
 	XDrawRectangle(disp, root, gc, x, y, w, h);
 
-	ESync(ESYNC_ICONIFY);
+	ESync(0);
 	IB_Animate_Sleep(t0, a);
 
 	XDrawRectangle(disp, root, gc, x, y, w, h);
@@ -298,13 +298,13 @@ IconboxesEwinIconify(EWin * ewin)
 {
    Container          *ct;
 
-   SoundPlay("SOUND_ICONIFY");
-
    ct = SelectIconboxForEwin(ewin);
    if (!ct)
       return;
 
-   if (ct->anim_mode && !ewin->state.showingdesk)
+   SoundPlay(SOUND_ICONIFY);
+
+   if (EoIsShown(ewin) && ct->anim_mode && !ewin->state.showingdesk)
       IB_Animate(ct, 1, ewin);
 
    IconboxObjEwinAdd(ct, ewin);
@@ -315,12 +315,12 @@ IconboxesEwinDeIconify(EWin * ewin)
 {
    Container          *ct;
 
-   SoundPlay("SOUND_DEICONIFY");
-
    ct = SelectIconboxForEwin(ewin);
    if (!ct)
       return;
 
+   SoundPlay(SOUND_DEICONIFY);
+
    if (ct->anim_mode && !ewin->state.showingdesk)
       IB_Animate(ct, 0, ewin);
 
