@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -29,6 +29,7 @@
 #include "eobj.h"
 #include "ewins.h"
 #include "ewin-ops.h"
+#include "focus.h"
 #include "grabs.h"
 #include "hints.h"		/* FIXME - Should not be here */
 #include "screen.h"
@@ -380,40 +381,45 @@ IPC_WinList(const char *params)
 static int
 doMoveConstrained(EWin * ewin, const char *params)
 {
-   return ActionMoveStart(ewin, params, 1, 0);
+   return ActionMoveStart(ewin, 0, params, 1, 0);
 }
 
 static int
 doMoveNoGroup(EWin * ewin, const char *params)
 {
-   return ActionMoveStart(ewin, params, 0, 1);
+   return ActionMoveStart(ewin, 0, params, 0, 1);
 }
 
 static int
 doSwapMove(EWin * ewin, const char *params)
 {
    Mode.move.swap = 1;
-   return ActionMoveStart(ewin, params, 0, 0);
+   return ActionMoveStart(ewin, 0, params, 0, 0);
 }
 
 static int
 doMoveConstrainedNoGroup(EWin * ewin, const char *params)
 {
-   return ActionMoveStart(ewin, params, 1, 1);
+   return ActionMoveStart(ewin, 0, params, 1, 1);
 }
 #endif
 
+static Timer       *op_timer = NULL;
+
 static int
 OpacityTimeout(void *data)
 {
    EWin               *ewin = (EWin *) data;
 
    if (!EwinFindByPtr(ewin))	/* May be gone */
-      return 0;
+      goto done;
 
    if (ewin->state.active)
       EoChangeOpacity(ewin, ewin->props.focused_opacity);
 
+ done:
+   ewin->state.show_coords = 0;
+   op_timer = NULL;
    return 0;
 }
 
@@ -560,7 +566,11 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	  }
 	if (!strcmp(param1, "ptr"))
 	  {
-	     ActionMoveStart(ewin, 0, Mode.nogroup);
+	     ActionMoveStart(ewin, 0, 0, Mode.nogroup);
+	  }
+	else if (!strcmp(param1, "kbd"))
+	  {
+	     ActionMoveStart(ewin, 1, 0, Mode.nogroup);
 	  }
 	else if (!strcmp(param1, "?"))
 	  {
@@ -588,15 +598,19 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 
 	if (!strcmp(param1, "ptr"))
 	  {
-	     ActionResizeStart(ewin, MODE_RESIZE);
+	     ActionResizeStart(ewin, 0, MODE_RESIZE);
 	  }
 	else if (!strcmp(param1, "ptr-h"))
 	  {
-	     ActionResizeStart(ewin, MODE_RESIZE_H);
+	     ActionResizeStart(ewin, 0, MODE_RESIZE_H);
 	  }
 	else if (!strcmp(param1, "ptr-v"))
 	  {
-	     ActionResizeStart(ewin, MODE_RESIZE_V);
+	     ActionResizeStart(ewin, 0, MODE_RESIZE_V);
+	  }
+	else if (!strcmp(param1, "kbd"))
+	  {
+	     ActionResizeStart(ewin, 1, MODE_RESIZE);
 	  }
 	else if (!strcmp(param1, "?"))
 	  {
@@ -692,14 +706,15 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	   b += a;
 	a = (b < 0) ? 1 : (b > 100) ? 100 : b;
 	EwinOpSetOpacity(ewin, OPSRC_USER, a);
-	if (ewin->state.active)
+	if (a && ewin->state.active)
 	  {
-	     Timer              *op_timer;
-
 	     EoChangeOpacity(ewin, OpacityFromPercent(a));
+	     TIMER_DEL(op_timer);
 	     if (ewin->props.focused_opacity)
 		TIMER_ADD(op_timer, 0.001 * 700, OpacityTimeout, ewin);
 	  }
+	if (ewin->state.in_action)
+	   CoordsShowOpacity(ewin);
 	break;
 
      case EWIN_OP_FOCUSED_OPACITY:
@@ -715,6 +730,8 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	   b += a;
 	a = (b < 0) ? 0 : (b > 100) ? 100 : b;
 	EwinOpSetFocusedOpacity(ewin, OPSRC_USER, a);
+	if (ewin->state.in_action)
+	   CoordsShowOpacity(ewin);
 	break;
 
      case EWIN_OP_SNAP:
@@ -739,6 +756,12 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	ewin->props.focusclick = on;
 	goto ewin_update_snap_flags;
 
+     case EWIN_OP_AUTOSHADE:
+	on = ewin->props.autoshade;
+	SetEwinBoolean(wop->name, &on, param1, 1);
+	ewin->props.autoshade = on;
+	goto ewin_update_snap_flags;
+
      case EWIN_OP_NO_BUTTON_GRABS:
 	on = ewin->props.no_button_grabs;
 	if (SetEwinBoolean(wop->name, &on, param1, 1))
@@ -960,11 +983,13 @@ IPC_Exit(const char *params)
       SessionExit(EEXIT_EXEC, p2);
 }
 
+#if ENABLE_DIALOGS
 static void
 IPC_About(const char *params __UNUSED__)
 {
    About();
 }
+#endif
 
 static void
 IPC_Version(const char *params __UNUSED__)
@@ -1243,8 +1268,15 @@ IPC_Warp(const char *params)
 	x = (Dpy.screen + 1) % ScreenCount(disp);
 	sscanf(params, "%*s %i", &x);
 	if (x >= 0 && x < ScreenCount(disp))
-	   EXWarpPointer(RootWindow(disp, x), DisplayWidth(disp, x) / 2,
-			 DisplayHeight(disp, x) / 2);
+	  {
+	     EXWarpPointer(RootWindow(disp, x), DisplayWidth(disp, x) / 2,
+			   DisplayHeight(disp, x) / 2);
+	     /* IIRC warping to a different screen once did cause
+	      * LeaveNotify's on the current root window. This does not
+	      * happen in xorg 1.5.3 (and probably other versions).
+	      * So, check and focus out if left. */
+	     FocusCheckScreen();
+	  }
      }
    else
      {
@@ -1497,10 +1529,12 @@ static const IpcItem IPCArray[] = {
     "nop", NULL,
     "IPC No-operation - returns nop",
     NULL},
+#if ENABLE_DIALOGS
    {
     IPC_About, "about", NULL, "Show E info", NULL},
    {
-    IPC_Cfg, "configure", "cfg", "Configuration", NULL},
+    IPC_Cfg, "configure", "cfg", "Configuration dialogs", NULL},
+#endif
    {
     IPC_Exec,
     "exec", NULL,
@@ -1543,7 +1577,7 @@ static const IpcItem IPCArray[] = {
 #endif
     "  win_op <windowid> desk <desktochangeto/next/prev>\n"
     "  win_op <windowid> area <x> <y>\n"
-    "  win_op <windowid> <move/size> <x> <y>\n"
+    "  win_op <windowid> <move/size> <x> <y> or <kbd/ptr>\n"
     "          (you can use ? and ?? to retreive client and frame locations)\n"
     "  win_op <windowid> <mr/sr> <x> <y>   (incremental move/size)\n"
     "  win_op <windowid> toggle_<width/height/size> <conservative/available/xinerama>\n"
