@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -42,7 +42,7 @@
 #include <signal.h>
 #include <time.h>
 
-const char          e_wm_name[] = "Enlightenment";
+const char          e_wm_name[] = "e16";
 const char          e_wm_version[] = VERSION;
 
 EConf               Conf;
@@ -287,7 +287,9 @@ main(int argc, char **argv)
 #endif
 
    ModulesSignal(ESIGNAL_START, NULL);
+#if ENABLE_DIALOGS
    DialogsInit();
+#endif
    EwinsManage();
 
    RunInitPrograms();
@@ -665,21 +667,6 @@ EGetSavePrefix(void)
    return def_prefix;
 }
 
-const char         *
-EGetSavePrefixCommon(void)
-{
-   static char        *pfx = NULL;
-   char                buf[1024];
-
-   if (pfx)
-      return pfx;
-
-   Esnprintf(buf, sizeof(buf), "%s/%s", EDirUser(), EConfName());
-   pfx = Estrdup(buf);
-
-   return pfx;
-}
-
 static void
 ECheckEprog(const char *name)
 {
