@@ -155,9 +155,10 @@ static const CfgItem MiscCfgItems[] = {
    CFG_ITEM_INT(Conf, movres.mode_info, 1),
    CFG_ITEM_INT(Conf, movres.mode_maximize_default, 1),
    CFG_ITEM_HEX(Conf, movres.color, 0x00ff0000),
-   CFG_ITEM_INT(Conf, movres.avoid_server_grab, 1),
+   CFG_ITEM_BOOL(Conf, movres.avoid_server_grab, 1),
    CFG_ITEM_BOOL(Conf, movres.update_while_moving, 0),
    CFG_ITEM_BOOL(Conf, movres.enable_sync_request, 0),
+   CFG_ITEM_BOOL(Conf, movres.dragbar_nocover, 0),
 
    CFG_ITEM_INT(Conf, opacity.menus, 85),
    CFG_ITEM_INT(Conf, opacity.movres, 60),
@@ -201,6 +202,7 @@ static const CfgItem MiscCfgItems[] = {
    CFG_ITEM_INT(Conf, testing.mask_alpha_threshold, 8),
    CFG_ITEM_BOOL(Conf, testing.enable_startup_id, 1),
    CFG_ITEM_BOOL(Conf, testing.use_render_for_scaling, 0),
+   CFG_ITEM_BOOL(Conf, testing.bindings_reload, 1),
    CFG_ITEM_HEX(Conf, testing.no_sync_mask, 0),
 
    CFG_ITEM_BOOL(Conf, autosave, 1),
@@ -210,75 +212,11 @@ static const CfgItem MiscCfgItems[] = {
 };
 #define N_CFG_ITEMS ((int)(sizeof(MiscCfgItems)/sizeof(CfgItem)))
 
-static void
-MiscIpcExec(const char *params)
-{
-   if (params)
-      execApplication(params, EXEC_SET_LANG | EXEC_SET_STARTUP_ID);
-   else
-      IpcPrintf("exec what?\n");
-}
-
-static void
-MiscIpcConfig(const char *params)
-{
-   const char         *p;
-   char                cmd[128], prm[128];
-   int                 len;
-
-   cmd[0] = prm[0] = '\0';
-   p = params;
-   if (p)
-     {
-	len = 0;
-	sscanf(p, "%100s %100s %n", cmd, prm, &len);
-	p += len;
-     }
-
-   if (!p || cmd[0] == '?')
-     {
-	/* Show info */
-     }
-   else if (!strncmp(cmd, "cfg", 3))
-     {
-	if (!strncmp(prm, "autoraise", 2))
-	   DialogShowSimple(&DlgAutoraise, NULL);
-	else if (!strncmp(prm, "misc", 2))
-	   DialogShowSimple(&DlgMisc, NULL);
-	else if (!strncmp(prm, "moveresize", 2))
-	   DialogShowSimple(&DlgMoveResize, NULL);
-	else if (!strncmp(prm, "placement", 2))
-	   DialogShowSimple(&DlgPlacement, NULL);
-	else if (!strncmp(prm, "remember", 2))
-	   DialogShowSimple(&DlgRemember, NULL);
-	else if (!strncmp(prm, "session", 2))
-	   DialogShowSimple(&DlgSession, NULL);
-	else if (prm[0] == '\0')
-	   SettingsConfiguration();
-     }
-}
-
-static const IpcItem MiscIpcArray[] = {
-   {
-    MiscIpcExec,
-    "exec", NULL,
-    "Execute program",
-    "  exec <command>           Execute command\n"}
-   ,
-   {
-    MiscIpcConfig,
-    "misc", NULL,
-    "Miscellaneous functions",
-    "  misc cfg <thing>         Configure thing (autoraise/misc/moveresize/placement/remember/session)\n"}
-};
-#define N_IPC_FUNCS (sizeof(MiscIpcArray)/sizeof(IpcItem))
-
 /* Stuff not elsewhere */
 const EModule       ModMisc = {
    "misc", NULL,
    NULL,
-   {N_IPC_FUNCS, MiscIpcArray}
-   ,
+   {0, NULL},
    {N_CFG_ITEMS, MiscCfgItems}
 };
 
@@ -291,7 +229,7 @@ autosave(void)
    if (EDebug(EDBUG_TYPE_SESSION))
       Eprintf("autosave\n");
 
-   Real_SaveSnapInfo(0, NULL);
+   SnapshotsSaveReal(NULL);
 
    /* Save the configuration parameters */
    ConfigurationSave();
