@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -516,9 +516,9 @@ PagerReconfigure(Pager * p, int apply)
 	   f = -f;
 	if (f < .1)
 	   break;
-	dx *= 2;
-	if (dx >= 16)
+	if (dx >= 8)
 	   break;
+	dx += 1;
      }
 
    ICCCM_SetSizeConstraints(p->ewin,
@@ -1393,7 +1393,7 @@ PagerEwinMove(Pager * p __UNUSED__, Pager * pd, EWin * ewin)
    dx = Mode.events.mx - Mode.events.px;
    dy = Mode.events.my - Mode.events.py;
 
-   if (dx == 0 && dy == 0)
+   if (dx == 0 && dy == 0 && p == pd)
       return;
 
    /* Move mini window */
@@ -1762,6 +1762,7 @@ PagersReconfigure(void)
    TIMER_ADD(pg_timer_cfg, .5, _PagersReconfigureTimeout, NULL);
 }
 
+#if ENABLE_DIALOGS
 /*
  * Configuration dialog
  */
@@ -1998,6 +1999,7 @@ const DialogDef     DlgPagers = {
    _DlgFillPagers,
    DLG_OAC, CB_ConfigurePager,
 };
+#endif /* ENABLE_DIALOGS */
 
 /*
  * Pagers Module
