@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -90,6 +90,9 @@ set_save_props(SmcConn smc_conn, int master_flag)
    const char         *sm_file;
    SmPropValue         discardVal[3];
    SmProp              discardProp;
+#endif
+#ifdef USE_EXT_INIT_WIN
+   char                bufx[32];
 #endif
    SmPropValue         restartVal[32];
    SmPropValue         styleVal;
@@ -192,8 +195,6 @@ set_save_props(SmcConn smc_conn, int master_flag)
 #ifdef USE_EXT_INIT_WIN
    if (restarting)
      {
-	char                bufx[32];
-
 	Esnprintf(bufx, sizeof(bufx), "%#lx", new_init_win_ext);
 	restartVal[n++].value = (char *)"-X";
 	restartVal[n++].value = bufx;
@@ -595,6 +596,7 @@ SessionLogout(void)
      }
 }
 
+#if ENABLE_DIALOGS
 static void
 LogoutCB(Dialog * d, int val, void *data __UNUSED__)
 {
@@ -665,6 +667,7 @@ SessionLogoutConfirm(void)
 
    DialogShowCentered(d);
 }
+#endif /* ENABLE_DIALOGS */
 
 void
 SessionExit(int mode, const char *param)
@@ -705,9 +708,11 @@ SessionExit(int mode, const char *param)
 	break;
 
      case EEXIT_LOGOUT:
+#if ENABLE_DIALOGS
 	if (Conf.session.enable_logout_dialog)
 	   SessionLogoutConfirm();
 	else
+#endif
 	   SessionLogout();
 	return;
      }
@@ -757,6 +762,7 @@ SessionHelper(int when)
      }
 }
 
+#if ENABLE_DIALOGS
 /*
  * Session dialog
  */
@@ -813,3 +819,4 @@ const DialogDef     DlgSession = {
    _DlgFillSession,
    DLG_OAC, CB_ConfigureSession,
 };
+#endif /* ENABLE_DIALOGS */
