@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -22,6 +22,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 #include "E.h"
+#if ENABLE_DIALOGS
 #include "dialog.h"
 #include "settings.h"
 
@@ -242,7 +243,7 @@ static int          tmp_shade_speed;
 static char         tmp_place_ignore_struts;
 static char         tmp_raise_fullscreen;
 
-#ifdef USE_XINERAMA
+#ifdef USE_XINERAMA_no		/* Not implemented */
 static char         tmp_extra_head;
 #endif
 
@@ -269,7 +270,7 @@ CB_ConfigurePlacement(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 
 	Conf.place.ignore_struts = tmp_place_ignore_struts;
 	Conf.place.raise_fullscreen = tmp_raise_fullscreen;
-#ifdef USE_XINERAMA
+#ifdef USE_XINERAMA_no		/* Not implemented */
 	if (Mode.display.xinerama_active)
 	   Conf.place.extra_head = tmp_extra_head;
 #endif
@@ -301,7 +302,7 @@ _DlgFillPlacement(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    tmp_place_ignore_struts = Conf.place.ignore_struts;
    tmp_raise_fullscreen = Conf.place.raise_fullscreen;
 
-#ifdef USE_XINERAMA
+#ifdef USE_XINERAMA_no		/* Not implemented */
    tmp_extra_head = Conf.place.extra_head;
 #endif
 
@@ -731,6 +732,7 @@ static const DialogDef *dialogs[] = {
    &DlgRemember,
    &DlgFx,
    &DlgBackground,
+   &DlgTheme,
 #ifdef ENABLE_THEME_TRANSPARENCY
    &DlgThemeTrans,
 #endif
@@ -817,3 +819,4 @@ IPC_Cfg(const char *params)
 	DialogShowSimple(dialogs[i], NULL);
      }
 }
+#endif /* ENABLE_DIALOGS */
