@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2007 Kim Woelders
+ * Copyright (C) 2006-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -23,6 +23,8 @@
 #ifndef _SETTINGS_H_
 #define _SETTINGS_H_
 
+#if ENABLE_DIALOGS
+
 /* settings.c */
 void                IPC_Cfg(const char *params);
 
@@ -43,8 +45,11 @@ extern const DialogDef DlgPlacement;
 extern const DialogDef DlgRemember;
 extern const DialogDef DlgSession;
 extern const DialogDef DlgSound;
+extern const DialogDef DlgTheme;
 extern const DialogDef DlgThemeTrans;
 extern const DialogDef DlgTooltips;
 #endif
 
+#endif /* ENABLE_DIALOGS */
+
 #endif /* _SETTINGS_H_ */
