@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -543,6 +543,7 @@ _EwinSnapRemove(EWin * ewin)
    ewin->snap = NULL;
 }
 
+#if ENABLE_DIALOGS
 /*
  * Snapshot dialogs
  */
@@ -1072,6 +1073,7 @@ const DialogDef     DlgRemember = {
    _DlgFillRemember,
    DLG_OC, CB_ApplyRemember,
 };
+#endif /* ENABLE_DIALOGS */
 
 /* ... combine writes, only save after a timeout */
 void
@@ -1536,11 +1538,13 @@ SnapshotEwinParse(EWin * ewin, const char *params)
 	  {
 	     use_flags = SNAP_USE_ALL;
 	  }
+#if ENABLE_DIALOGS
 	else if (!strcmp(param, "dialog"))
 	  {
 	     _EwinSnapDialog(ewin);
 	     break;
 	  }
+#endif
 	else if (!strcmp(param, "none"))
 	   _EwinSnapRemove(ewin);
 	else if (!strcmp(param, "auto"))
