@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -103,8 +103,7 @@ StartupWindowsCreate(void)
 
    BackgroundSet(bg, win1, WinGetW(VROOT), WinGetH(VROOT));
    BackgroundSet(bg, win2, WinGetW(VROOT), WinGetH(VROOT));
-   BackgroundDestroyByName("STARTUP_BACKGROUND_SIDEWAYS");
-   BackgroundDestroyByName("STARTUP_BACKGROUND");
+   StartupBackgroundsDestroy();
 
    EobjMap(init_win1, 0);
    EobjMap(init_win2, 0);
@@ -112,6 +111,13 @@ StartupWindowsCreate(void)
    EobjsRepaint();
 }
 
+void
+StartupBackgroundsDestroy(void)
+{
+   BackgroundDestroyByName("STARTUP_BACKGROUND");
+   BackgroundDestroyByName("STARTUP_BACKGROUND_SIDEWAYS");
+}
+
 static int
 doStartupWindowsOpen(void *data __UNUSED__)
 {
