@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -418,11 +418,8 @@ SystrayItemEvent(Win win, XEvent * ev, void *prm)
 static void
 SystrayInit(Container * ct)
 {
-   char                buf[32];
    Win                 win;
 
-   Esnprintf(buf, sizeof(buf), "_NET_SYSTEM_TRAY_S%d", Dpy.screen);
-
    E_XA__XEMBED = EInternAtom("_XEMBED");
    E_XA__XEMBED_INFO = EInternAtom("_XEMBED_INFO");
    _NET_SYSTEM_TRAY_OPCODE = EInternAtom("_NET_SYSTEM_TRAY_OPCODE");
@@ -486,6 +483,10 @@ SystrayObjPlace(Container * ct __UNUSED__, ContainerObject * cto,
      {
 	EMoveResizeWindow(StObjGetWin(cto->obj), cto->xi, cto->yi, cto->wi,
 			  cto->hi);
+	/* This seems to fix rendering for ceratin apps which seem to expect
+	 * expose events after resize (e.g. opera) */
+	ESync(0);
+	XClearArea(disp, WinGetXwin(StObjGetWin(cto->obj)), 0, 0, 0, 0, True);
      }
 }
 
