@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -162,12 +162,6 @@ ThemesList(int *number)
    return list;
 }
 
-static void
-ThemeCleanup(void)
-{
-   /* TBD */
-}
-
 static const char  *
 ThemeGetPath(const char *path, char *buf, unsigned int len)
 {
@@ -255,8 +249,6 @@ ThemeExtract(const char *path)
       return Estrdup(path);
 
    /* failed */
-   ThemeCleanup();
-
    return NULL;
 }
 
@@ -278,18 +270,16 @@ ThemeFind(const char *theme)
      {
 	theme = NULL;
      }
-   else
+   else if (!strcmp(theme, "-"))	/* Use fallbacks */
      {
-	if (!strcmp(theme, "-"))	/* Use fallbacks */
-	   return NULL;
-
-	if (isabspath(theme))
-	  {
-	     path = ThemeExtract(theme);
-	     if (path)
-		return path;
-	     theme = NULL;
-	  }
+	return NULL;
+     }
+   else if (isabspath(theme))
+     {
+	path = ThemeExtract(theme);
+	if (path)
+	   return path;
+	theme = NULL;
      }
 
    lst = StrlistFromString(Mode.theme.paths, ':', &num);
@@ -332,23 +322,19 @@ ThemeFind(const char *theme)
    return path;
 }
 
-/*
- * Theme module
- */
-
 void
 ThemePathFind(void)
 {
-   char               *theme;
+   char               *name, *path;
 
    /*
     * Conf.theme.name is read from the configuration.
     * Mode.theme.path may be assigned on the command line.
     */
-   theme = (Mode.theme.path) ? Mode.theme.path : Conf.theme.name;
-   theme = ThemeFind(theme);
+   name = (Mode.theme.path) ? Mode.theme.path : Conf.theme.name;
+   path = ThemeFind(name);
 
-   if (!theme)
+   if (!path && (!name || strcmp(name, "-")))
      {
 	Alert(_("No themes were found in the default directories:\n"
 		" %s\n"
@@ -357,25 +343,76 @@ ThemePathFind(void)
      }
 
    Efree(Conf.theme.name);
-   Conf.theme.name = ThemePathName(theme);
+   Conf.theme.name = ThemePathName(path);
 
    Efree(Mode.theme.path);
-   Mode.theme.path = (theme) ? theme : Estrdup("-");
+   Mode.theme.path = (path) ? path : Estrdup("-");
+}
+
+#if ENABLE_DIALOGS
+#include "dialog.h"
+/*
+ * Configuration dialog
+ */
+static char         tmp_use_theme_font;
+static char         tmp_use_alt_font;
+
+static void
+_DlgThemeConfigure(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
+{
+   if (val >= 2)
+      return;
+   if (Conf.theme.use_theme_font_cfg == tmp_use_theme_font &&
+       Conf.theme.use_alt_font_cfg == tmp_use_alt_font)
+      return;
+
+   DialogOK(_("Message"), _("Changes will take effect after restart"));
+
+   Conf.theme.use_theme_font_cfg = tmp_use_theme_font;
+   Conf.theme.use_alt_font_cfg = tmp_use_alt_font;
+   autosave();
 }
 
 static void
-ThemesSighan(int sig, void *prm __UNUSED__)
+_DlgThemeFill(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
 {
-   switch (sig)
-     {
-     case ESIGNAL_CONFIGURE:
-	break;
-     case ESIGNAL_EXIT:
-	ThemeCleanup();
-	break;
-     }
+   DItem              *di;
+   char                buf[1024];
+
+   tmp_use_theme_font = Conf.theme.use_theme_font_cfg;
+   tmp_use_alt_font = Conf.theme.use_alt_font_cfg;
+
+   DialogItemTableSetOptions(table, 2, 0, 0, 0);
+
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   DialogItemSetText(di, _("Use theme font configuration"));
+   DialogItemCheckButtonSetPtr(di, &tmp_use_theme_font);
+
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   Esnprintf(buf, sizeof(buf), _("Use alternate font configuration (%s)"),
+	     Conf.theme.font_cfg ? Conf.theme.font_cfg : _("Not set"));
+   DialogItemSetText(di, buf);
+   DialogItemCheckButtonSetPtr(di, &tmp_use_alt_font);
 }
 
+const DialogDef     DlgTheme = {
+   "CONFIGURE_AUDIO",
+   N_("Theme"),
+   N_("Theme Settings"),
+   SOUND_SETTINGS_MISCELLANEOUS,
+   "pix/miscellaneous.png",
+   N_("Enlightenment Theme\n" "Settings Dialog\n"),
+   _DlgThemeFill,
+   DLG_OAC, _DlgThemeConfigure,
+};
+#endif /* ENABLE_DIALOGS */
+
+/*
+ * Theme module
+ */
+
 static void
 ThemesIpc(const char *params)
 {
@@ -396,7 +433,7 @@ ThemesIpc(const char *params)
      {
 	char               *path;
 
-	IpcPrintf("Name: %s\n", Conf.theme.name);
+	IpcPrintf("Name: %s\n", (Conf.theme.name) ? Conf.theme.name : "-");
 	IpcPrintf("Full: %s\n", Mode.theme.path);
 	path = ThemeFind(NULL);
 	IpcPrintf("Default: %s\n", path);
@@ -437,7 +474,8 @@ static const IpcItem ThemeIpcArray[] = {
 static const CfgItem ThemeCfgItems[] = {
    CFG_ITEM_STR(Conf.theme, name),
    CFG_ITEM_STR(Conf.theme, extra_path),
-   CFG_ITEM_BOOL(Conf.theme, use_alt_font_cfg, 1),
+   CFG_ITEM_BOOL(Conf.theme, use_theme_font_cfg, 0),
+   CFG_ITEM_BOOL(Conf.theme, use_alt_font_cfg, 0),
    CFG_ITEM_STR(Conf.theme, font_cfg),
 };
 #define N_CFG_ITEMS (sizeof(ThemeCfgItems)/sizeof(CfgItem))
@@ -448,7 +486,7 @@ static const CfgItem ThemeCfgItems[] = {
 extern const EModule ModTheme;
 const EModule       ModTheme = {
    "theme", "th",
-   ThemesSighan,
+   NULL,
    {N_IPC_FUNCS, ThemeIpcArray},
    {N_CFG_ITEMS, ThemeCfgItems}
 };
