@@ -23,13 +23,18 @@
  */
 #define DECLARE_WIN 1
 #include "E.h"
+#include "edebug.h"
+#include "util.h"
+#include "xwin.h"
+#include <string.h>
+#include <unistd.h>
 #ifdef USE_ECORE_X
 #include <Ecore_X.h>
 #endif
-#include "xwin.h"
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
 #include <X11/Xresource.h>
+#include <X11/extensions/shape.h>
 #if USE_COMPOSITE
 #include <X11/extensions/Xrender.h>
 #endif
@@ -251,7 +256,8 @@ EventCallbackRegister(Win win, int type __UNUSED__, EventCallbackFunc * func,
    if (!win)
       return;
 #if 0
-   Eprintf("EventCallbackRegister: %p %#lx\n", win, win->xwin);
+   Eprintf("EventCallbackRegister: %p %#lx: func=%p prm=%p\n", win, win->xwin,
+	   func, prm);
 #endif
 
    win->cbl.num++;
@@ -272,7 +278,8 @@ EventCallbackUnregister(Win win, int type __UNUSED__,
    if (!win)
       return;
 #if 0
-   Eprintf("EventCallbackUnregister: %p %#lx\n", win, win->xwin);
+   Eprintf("EventCallbackUnregister: %p %#lx: func=%p prm=%p\n", win, win->xwin,
+	   func, prm);
 #endif
 
    ecl = &win->cbl;
@@ -439,17 +446,19 @@ ECreateObjectWindow(Win parent, int x, int y, int w, int h, int saveunder,
 
    switch (type)
      {
-     case 0:			/* Client window */
+     default:
+     case WIN_TYPE_NO_ARGB:
+	break;
+     case WIN_TYPE_CLIENT:
 	if (Conf.testing.argb_clients || EVisualIsARGB(cwin->visual))
 	   argb = 1;
 	break;
-     default:
-     case 1:			/* Internal */
+     case WIN_TYPE_INTERNAL:
 	if (Conf.testing.argb_internal_objects)
 	   argb = 1;
 	break;
 #if USE_GLX
-     case 2:			/* Internal GL */
+     case WIN_TYPE_GLX:	/* Internal GL */
 	argb = 1;
 	win =
 	   ECreateWindowVD(parent, x, y, w, h, EGlGetVisual(), EGlGetDepth());
@@ -1290,7 +1299,7 @@ EShapeUpdate(Win win)
 #endif
 }
 
-void
+static void
 EShapeCombineMask(Win win, int dest, int x, int y, Pixmap pmap, int op)
 {
    char                wasshaped = 0;
@@ -1319,7 +1328,7 @@ EShapeCombineMask(Win win, int dest, int x, int y, Pixmap pmap, int op)
       XShapeCombineMask(disp, win->xwin, dest, x, y, pmap, op);
 }
 
-void
+static void
 EShapeCombineMaskTiled(Win win, int dest, int x, int y,
 		       Pixmap pmap, int op, int w, int h)
 {
@@ -1340,7 +1349,7 @@ EShapeCombineMaskTiled(Win win, int dest, int x, int y,
    EFreePixmap(tm);
 }
 
-void
+static void
 EShapeCombineRectangles(Win win, int dest, int x, int y,
 			XRectangle * rect, int n_rects, int op, int ordering)
 {
@@ -1378,100 +1387,15 @@ EShapeCombineRectangles(Win win, int dest, int x, int y,
    EShapeUpdate(win);
 }
 
-#if 0				/* Unused */
-XRectangle         *
-EShapeGetRectangles(Win win, int dest, int *rn, int *ord)
+static void
+EShapeCombineShape(Win win, int dest, int x, int y,
+		   Win src_win, int src_kind, int op)
 {
    if (!win)
-      return NULL;
+      return;
 
-   if (!win->attached)
-     {
-	XRectangle         *r;
-
-#if DEBUG_SHAPE_OPS
-	Eprintf("EShapeGetRectangles-A %#lx nr=%d\n", win->xwin, win->num_rect);
-#endif
-	*rn = win->num_rect;
-	*ord = win->ord;
-	if (win->num_rect > 0)
-	  {
-	     r = EMALLOC(XRectangle, win->num_rect);
-	     if (!r)
-		return NULL;
-	     memcpy(r, win->rects, sizeof(XRectangle) * win->num_rect);
-	     return r;
-	  }
-     }
-   else
-     {
-	XRectangle         *r, *rr;
-
-#if DEBUG_SHAPE_OPS
-	Eprintf("EShapeGetRectangles-B %#lx nr=%d\n", win->xwin, win->num_rect);
-#endif
-	r = XShapeGetRectangles(disp, win->xwin, dest, rn, ord);
-	if (r)
-	  {
-	     rr = EMALLOC(XRectangle, *rn);
-	     if (!rr)
-		return NULL;
-	     memcpy(rr, r, sizeof(XRectangle) * *rn);
-	     XFree(r);
-	     return rr;
-	  }
-     }
-   return NULL;
-}
-#endif
-
-int
-EShapeCopy(Win dst, Win src)
-{
-   XRectangle         *rl;
-   int                 rn;
-
-   if (!src || !dst)
-      return 0;
-
-   if (src->attached)
-      EShapeUpdate(src);
-
-   rn = src->num_rect;
-   rl = src->rects;
-
-   if (rn < 0)
-     {
-	/* Source has empty shape */
-	EShapeCombineShape(dst, ShapeBounding, 0, 0,
-			   src, ShapeBounding, ShapeSet);
-     }
-   else if (rn == 0)
-     {
-	/* Source has default shape (no shape) */
-	EShapeCombineMask(dst, ShapeBounding, 0, 0, None, ShapeSet);
-     }
-   else if (rn == 1)
-     {
-	if ((rl[0].x <= 0) && (rl[0].y <= 0) && (rl[0].width >= src->w)
-	    && (rl[0].height >= src->h))
-	  {
-	     rn = 0;
-	     EShapeCombineMask(dst, ShapeBounding, 0, 0, None, ShapeSet);
-	  }
-	else
-	  {
-	     EShapeCombineShape(dst, ShapeBounding, 0, 0,
-				src, ShapeBounding, ShapeSet);
-	  }
-     }
-   else
-     {
-	EShapeCombineShape(dst, ShapeBounding, 0, 0,
-			   src, ShapeBounding, ShapeSet);
-     }
-
-   return rn != 0;
+   XShapeCombineShape(disp, win->xwin, dest, x, y, src_win->xwin, src_kind, op);
+   EShapeUpdate(win);
 }
 
 int
@@ -1583,17 +1507,6 @@ EShapePropagate(Win win)
    return 0;
 }
 
-void
-EShapeCombineShape(Win win, int dest, int x, int y,
-		   Win src_win, int src_kind, int op)
-{
-   if (!win)
-      return;
-
-   XShapeCombineShape(disp, win->xwin, dest, x, y, src_win->xwin, src_kind, op);
-   EShapeUpdate(win);
-}
-
 int
 EShapeCheck(Win win)
 {
@@ -1603,6 +1516,75 @@ EShapeCheck(Win win)
    return win->num_rect;
 }
 
+void
+EShapeSetMask(Win win, int x, int y, Pixmap mask)
+{
+   EShapeCombineMask(win, ShapeBounding, x, y, mask, ShapeSet);
+}
+
+void
+EShapeUnionMask(Win win, int x, int y, Pixmap mask)
+{
+   EShapeCombineMask(win, ShapeBounding, x, y, mask, ShapeUnion);
+}
+
+void
+EShapeSetMaskTiled(Win win, int x, int y, Pixmap mask, int w, int h)
+{
+   EShapeCombineMaskTiled(win, ShapeBounding, x, y, mask, ShapeSet, w, h);
+}
+
+void
+EShapeSetRects(Win win, int x, int y, XRectangle * rect, int n_rects)
+{
+   EShapeCombineRectangles(win, ShapeBounding, x, y, rect, n_rects,
+			   ShapeSet, Unsorted);
+}
+
+void
+EShapeUnionRects(Win win, int x, int y, XRectangle * rect, int n_rects)
+{
+   EShapeCombineRectangles(win, ShapeBounding, x, y, rect, n_rects,
+			   ShapeUnion, Unsorted);
+}
+
+int
+EShapeSetShape(Win win, int x, int y, Win src_win)
+{
+   EShapeCombineShape(win, ShapeBounding, x, y,
+		      src_win, ShapeBounding, ShapeSet);
+   return win->num_rect != 0;
+}
+
+/* Build mask from window shape rects */
+Pixmap
+EWindowGetShapePixmap(Win win)
+{
+   Pixmap              mask;
+   GC                  gc;
+   int                 i;
+   const XRectangle   *rect;
+
+   if (win->num_rect == 0)	/* Not shaped */
+      return None;
+
+   mask = ECreatePixmap(win, win->w, win->h, 1);
+   gc = EXCreateGC(mask, 0, NULL);
+
+   XSetForeground(disp, gc, 0);
+   XFillRectangle(disp, mask, gc, 0, 0, win->w, win->h);
+
+   XSetForeground(disp, gc, 1);
+   rect = win->rects;
+   for (i = 0; i < win->num_rect; i++)
+      XFillRectangle(disp, mask, gc, rect[i].x, rect[i].y,
+		     rect[i].width, rect[i].height);
+
+   EXFreeGC(gc);
+
+   return mask;
+}
+
 Pixmap
 ECreatePixmap(Win win, unsigned int width, unsigned int height,
 	      unsigned int depth)
@@ -1724,40 +1706,6 @@ EAllocXColor(Colormap cmap, XColor * pxc, EColor * pec)
    XAllocColor(disp, cmap, pxc);
 }
 
-/* Build mask from window shape rects */
-/* Snatched from imlib_create_scaled_image_from_drawable() */
-Pixmap
-EWindowGetShapePixmap(Win win)
-{
-   Pixmap              mask;
-   GC                  gc;
-   XRectangle         *rect;
-   int                 i, w, h;
-   int                 rect_num, rect_ord;
-
-   EGetGeometry(win, NULL, NULL, NULL, &w, &h, NULL, NULL);
-   mask = ECreatePixmap(win, w, h, 1);
-
-   gc = EXCreateGC(mask, 0, NULL);
-   XSetForeground(disp, gc, 0);
-
-   rect =
-      XShapeGetRectangles(disp, win->xwin, ShapeBounding, &rect_num, &rect_ord);
-   XFillRectangle(disp, mask, gc, 0, 0, w, h);
-   if (rect)
-     {
-	XSetForeground(disp, gc, 1);
-	for (i = 0; i < rect_num; i++)
-	   XFillRectangle(disp, mask, gc, rect[i].x, rect[i].y,
-			  rect[i].width, rect[i].height);
-	XFree(rect);
-     }
-
-   EXFreeGC(gc);
-
-   return mask;
-}
-
 /*
  * Display
  */
@@ -1770,7 +1718,7 @@ EDisplayOpen(const char *dstr, int scr)
    if (scr >= 0)
      {
 	/* Override screen */
-	Esnprintf(dbuf, sizeof(dbuf) - 10, dstr);
+	Esnprintf(dbuf, sizeof(dbuf) - 10, "%s", dstr);
 	s = strchr(dbuf, ':');
 	if (s)
 	  {
