@@ -25,7 +25,6 @@
 #define _XWIN_H_
 
 #include <X11/Xlib.h>
-#include <X11/extensions/shape.h>
 #include "util.h"
 #include "xtypes.h"
 
@@ -68,7 +67,6 @@ void                EFlush(void);
 #define ESYNC_MENUS	0x0004
 #define ESYNC_MOVRES	0x0008
 #define ESYNC_FOCUS	0x0010
-#define ESYNC_ICONIFY	0x0020
 #define ESYNC_TLOOP	0x0040
 #define ESYNC_SLIDEOUT	0x0080
 #define ESYNC_STARTUP	0x0100
@@ -166,6 +164,11 @@ Win                 ECreateArgbWindow(Win parent, int x, int y, int w, int h,
 Win                 ECreateWindowVD(Win parent, int x, int y, int w, int h,
 				    Visual * vis, unsigned int depth);
 Win                 ECreateClientWindow(Win parent, int x, int y, int w, int h);
+
+#define WIN_TYPE_CLIENT     0
+#define WIN_TYPE_INTERNAL   1
+#define WIN_TYPE_NO_ARGB    2
+#define WIN_TYPE_GLX        3
 Win                 ECreateObjectWindow(Win parent, int x, int y, int w,
 					int h, int saveunder, int type,
 					Win cwin);
@@ -217,17 +220,15 @@ Pixmap              ECreatePixmap(Win win, unsigned int width,
 				  unsigned int height, unsigned int depth);
 void                EFreePixmap(Pixmap pixmap);
 
-void                EShapeCombineMask(Win win, int dest, int x, int y,
-				      Pixmap pmap, int op);
-void                EShapeCombineMaskTiled(Win win, int dest, int x, int y,
-					   Pixmap pmap, int op, int w, int h);
-void                EShapeCombineRectangles(Win win, int dest, int x, int y,
-					    XRectangle * rect, int n_rects,
-					    int op, int ordering);
-void                EShapeCombineShape(Win win, int dest, int x, int y,
-				       Win src_win, int src_kind, int op);
-XRectangle         *EShapeGetRectangles(Win win, int dest, int *rn, int *ord);
-int                 EShapeCopy(Win dst, Win src);
+void                EShapeSetMask(Win win, int x, int y, Pixmap mask);
+void                EShapeUnionMask(Win win, int x, int y, Pixmap mask);
+void                EShapeSetMaskTiled(Win win, int x, int y, Pixmap mask,
+				       int w, int h);
+void                EShapeSetRects(Win win, int x, int y,
+				   XRectangle * rect, int n_rects);
+void                EShapeUnionRects(Win win, int x, int y,
+				     XRectangle * rect, int n_rects);
+int                 EShapeSetShape(Win win, int x, int y, Win src_win);
 int                 EShapePropagate(Win win);
 int                 EShapeCheck(Win win);
 Pixmap              EWindowGetShapePixmap(Win win);
